.. _spec:

Parameter Specification
=======================

This section contains the detailed specification of all contributions entering the tight-binding Hamiltonian.
Additionally, the format to construct the Hamiltonian is described for writing :ref:`parameter files <parameter>`.
A list of :ref:`built-in methods <methods>` is available as well.

.. toctree::

   methods
   hamiltonian
   repulsion
   coulomb
   dispersion
   parameter
